// This Javascript is responsible for...
// ...the header and its design (width, elements) depending on the device's size. 
// ...the navigation sidebars on the left and right, and shows or hides them depending on display's size
// ...the pages main content's width

document.addEventListener("DOMContentLoaded", function() {
  adjustStyles();

  window.addEventListener('resize', adjustStyles);
});

function adjustStyles() {
  // var tabs = document.querySelector('.md-tabs');
  var headerInner = document.querySelector('.md-header__inner.md-grid');
  var title = document.querySelector('.md-header__title');
  var ellipsis = document.querySelector('.md-ellipsis');
  // var source = document.querySelector('.md-header__source');
  var content = document.querySelector('.md-content');
  var primarySidebar = document.querySelector('.md-sidebar--primary');
  var secondarySidebar = document.querySelector('.md-sidebar--secondary');
  var mdMainInnerGrid = document.querySelector('.md-main__inner.md-grid'); 
  secondarySidebar.style.display = 'none'; //Table of Contents: always hidden


  if (tabs && headerInner && title && ellipsis && content && primarySidebar && secondarySidebar) {
    // get computed styles
    // var tabsDisplay = window.getComputedStyle(tabs).display;
    var primaryDisplay = window.getComputedStyle(primarySidebar).display;
    var secondaryDisplay = window.getComputedStyle(secondarySidebar).display;

    // Reset all styles
    headerInner.style.width = '';
    content.style.width = '';
    content.style.flexGrow = '';
    headerInner.style.marginLeft = '';
    headerInner.style.visibility = 'visible'; // Always visible
    title.style.visibility = '';
    ellipsis.style.visibility = '';
    // source.style.display = '';
    content.style.marginRight = '';
    body.style.visibility = 'hidden';
    mdMainInnerGrid.style.paddingLeft = '';

    // Check the conditions and apply styles accordingly
    if (tabsDisplay !== 'none') {
      var mdTabsWidth = tabs.offsetWidth
      var tabsWidth = tabs.offsetWidth + 'px';
      var displayWidth = window.innerWidth;
      var mdSidebarWidth = document.querySelector('.md-sidebar.md-sidebar--primary').offsetWidth;
      var paddingLeft = (displayWidth - mdTabsWidth - (2 * mdSidebarWidth)) / 2; // calculates padding to make sure content and tabs stay aligned
      headerInner.style.width = tabsWidth;
      title.style.visibility = 'hidden';
      ellipsis.style.visibility = 'hidden';
      // source.style.display = 'block';

      if (primaryDisplay !== 'none' || secondaryDisplay !== 'none') {
        content.style.width = tabsWidth;
        content.style.flexGrow = '0';
        // makes sure content and tabs stay aligned
        if (mdMainInnerGrid) { // Check if the element exists to avoid errors
            mdMainInnerGrid.style.paddingLeft = `${paddingLeft}px`; // Set padding-left, converting value to a string with 'px'
        } else {
            console.error("Element '.md-main__inner.md-grid' not found.");
        }
      }

      if (primaryDisplay !== 'none' && secondaryDisplay === 'none') {
        content.style.marginRight = primarySidebar.offsetWidth + 'px';
      }
    } else {
      headerInner.style.width = '100%';
      headerInner.style.marginLeft = '0';
      // source.style.display = 'none';
      title.style.visibility = 'visible';
      ellipsis.style.visibility = 'visible';
    }

    if (primaryDisplay === 'none' && secondaryDisplay === 'none') {
      content.style.width = '95%';
      content.style.flexGrow = '1';
    }
  } else {
    console.log("One or more elements are missing from the DOM.");
  }
  body.style.visibility = 'visible';
}

// set paths of the footer logos dynamically depending on host
// maybe redundant, needs testing
document.addEventListener('DOMContentLoaded', () => {
  var copy1;
  var copy2;
  var copy3;
  var hostname = window.location.hostname;
  var pathname = window.location.pathname;

  if (hostname === 'localhost') {
    copy1 = "/medien/logo-rub.png";
    copy2 = "/medien/logo-worldfactory.png";
    copy3 = "/medien/logo-esc.png";
  } 
  else if (hostname.includes('makerspace.ruhr-uni-bochum.de')) {
    copy1 = "/medien/logo-rub.png";
    copy2 = "/medien/logo-worldfactory.png";
    copy3 = "/medien/logo-esc.png";
  } 
  else if (hostname.includes('ruhr-uni-bochum.de') && pathname.includes('/makerspace/')) {
    copy1 = "/makerspace/medien/logo-rub.png";
    copy2 = "/makerspace/medien/logo-worldfactory.png";
    copy3 = "/makerspace/medien/logo-esc.png";
  }

  document.getElementById('copyright1').src = copy1;
  document.getElementById('copyright2').src = copy2;
  document.getElementById('copyright3').src = copy3;
});

// Inserts Sidebar (left) navigation-title
document.addEventListener("DOMContentLoaded", function() {
  // Create the navigation header element
  var navHeader = document.createElement("h1");
  navHeader.className = "custom-nav-header"; // Add custom class for styling
  
  // Check if the current URL contains '/en/' to determine the language
  if (window.location.pathname.includes("/en/")) {
    navHeader.innerText = "Navigation Menu"; // English title
  } else {
    navHeader.innerText = "Navigationsmenü"; // German title
  }
  
  // Insert the navigation header into the sidebar
  var sidebar = document.querySelector(".md-sidebar--primary .md-sidebar__inner");
  if (sidebar) {
    sidebar.insertBefore(navHeader, sidebar.firstChild);
  }
});

// Protects the ears of our dear visitors by setting the starting volume of our videos to a low amount
document.addEventListener("DOMContentLoaded", function() {
  // Select all video elements on the page
  var videos = document.querySelectorAll("video");
  
  // Loop through each video
  if (videos){
    for(var i = 0; i < videos.length; i++) {
      // Set the volume to your desired level (e.g., 0.2)
      videos[i].volume = 0.1;
    }
  }
});

document.addEventListener('DOMContentLoaded', function() {
  var videoContainers = document.querySelectorAll('.video-container');

  videoContainers.forEach(function(container) {
      var video = container.querySelector('video');
      var videoSrc = video.querySelector('source').src;
      var thumbnailSrc = videoSrc.replace('.mp4', '.jpg'); // Assuming a naming convention for thumbnails

      // Create thumbnail
      var img = document.createElement('img');
      img.src = thumbnailSrc;
      img.className = 'video-thumbnail';

      // Create play button
      var playButton = document.createElement('button');
      playButton.className = 'play-button';

      // When play button is clicked
      playButton.addEventListener('click', function() {
          // Replace the thumbnail and play button with the video
          container.innerHTML = '';
          container.appendChild(video);
          video.play();
      });

      // Clear the container and add the thumbnail and play button
      container.innerHTML = '';
      container.appendChild(img);
      container.appendChild(playButton);
  });
});